==> pdrx-1.5.0.tar.bz2: pdrx-1.5.0/src/pdx/db_impl_mysql.cc <==
// This file is part of the pdr/pdx project.
// Copyright (C) 2010 Torsten Mueller, Bern, Switzerland
//
// This program is free software: you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation, either version 2 of the
// License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.

#ifdef USE_MYSQL

#include "../libpdrx/common.h"

#include <Poco/Data/Common.h>
#include <Poco/Data/MySQL/Connector.h>
#include <Poco/Data/MySQL/MySQLException.h>

using namespace std;
using namespace boost;
using namespace boost::posix_time;
using namespace boost::gregorian;
using namespace boost::program_options;
using namespace Poco::Data;

#include "../libpdrx/datatypes.h"
#include "config_impl.h"
#include "db_impl.h"

//=== MySQLDatabase ========================================================
MySQLDatabase::MySQLDatabase (const string& connect, bool verbose, bool fast)
	: PocoDatabaseImpl(connect, verbose, fast, MySQL::Connector::KEY, new MySQL::Connector())
{
}

string MySQLDatabase::GetVersion () const throw (Xception)
{
	try
	{
		string version;
		(*m_pSession) << "select version();", into(version), now;
		return string("MySQL ") + version;
	}
	catch (...)
	{
		throw Xception("error determining database version");
	}
}

#endif // USE_MYSQL

==> pdrx-1.7.0.tar.bz2: pdrx-1.7.0/src/pdx/db_impl_mysql.cc <==
// This file is part of the pdr/pdx project.
// Copyright (C) 2010 Torsten Mueller, Bern, Switzerland
//
// This program is free software: you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation, either version 2 of the
// License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.

#include "../libpdrx/common.h"

#ifdef USE_MYSQL

#include <Poco/Data/Common.h>
#include <Poco/Data/MySQL/Connector.h>
#include <Poco/Data/MySQL/MySQLException.h>

using namespace std;
using namespace boost;
using namespace boost::posix_time;
using namespace boost::gregorian;
using namespace boost::program_options;
using namespace Poco::Data;

#include "../libpdrx/datatypes.h"
#include "../libpdrx/xception.h"
#include "config_impl.h"
#include "db_impl.h"

//=== MySQLDatabase ========================================================
MySQLDatabase::MySQLDatabase (const string& connect, bool verbose, bool fast)
	: PocoDatabaseImpl(connect, verbose, fast, MySQL::Connector::KEY, new MySQL::Connector())
{
}

string MySQLDatabase::GetVersion () const throw (Xception)
{
	try
	{
		string version;
		(*m_pSession) << "select version();", into(version), now;
		return string("MySQL ") + version;
	}
	CATCH_RETHROW("error determining database version")
}

#endif // USE_MYSQL
